@@ -10,31 +10,50 @@ d
 
 ## ------------------------------------------------------------------------
 library(units)
-(a = as.units(1:10, "m/s"))
+m <- make_unit("m")
+s <- make_unit("s")
+
+## ------------------------------------------------------------------------
+m
+
+## ------------------------------------------------------------------------
+(a <- 1:10 * m/s)
+
+## ------------------------------------------------------------------------
+a[10]
+
+## ------------------------------------------------------------------------
+rm(m) ; rm(s)
+with(ud_units, 1:10 * m/s)
 
 ## ------------------------------------------------------------------------
 b = a
-units(b) = "km/h"
+units(b) <- with(ud_units, km/h)
 b
 
-## ------------------------------------------------------------------------
-x = try(units(a) <- "secs")
-attr(x, "condition")[[1]]
-
 ## ------------------------------------------------------------------------
 a + a
 a * a
-a ^ 2.5
+a ^ 2
+a ** -2
 
 ## ------------------------------------------------------------------------
 a + b # m/s + km/h -> m/s
 
 ## ------------------------------------------------------------------------
-t = as.units(1, "s")
+t <- with(ud_units, s)
 a * t
 
 ## ------------------------------------------------------------------------
-signif(a^2.5, 3)
+t <- with(ud_units, min)
+a * t
+
+## ------------------------------------------------------------------------
+m <- with(ud_units, m)
+a * t / m
+
+## ------------------------------------------------------------------------
+signif(a ** 2 / 3, 3)
 cumsum(a)
 log(a) # base defaults to exp(1)
 log(a, base = 10)
@@ -45,7 +64,7 @@ sum(a)
 min(a)
 max(a)
 range(a)
-min(as.units(1, "m/s"), as.units(1, "km/h")) # converts to first unit:
+with(ud_units, min(m/s, km/h)) # converts to first unit:
 
 ## ------------------------------------------------------------------------
 a
@@ -66,8 +85,7 @@ c(b,a) # km/h, m/s -> km/h
 t1 = Sys.time() 
 t2 = t1 + 3600 
 d = t2 - t1
-as.units(d)
-(du = as.units(d, "d"))
+du <- as.units(d)
 
 ## ------------------------------------------------------------------------
 dt = as.dt(du)
@@ -75,18 +93,39 @@ class(dt)
 dt
 
 ## ------------------------------------------------------------------------
-as.units(matrix(1:4,2,2), "m/s")
-as.units(matrix(1:4,2,2), "m/s") * as.units(4, "m/s")
+with(ud_units, matrix(1:4,2,2) * m/s)
+with(ud_units, matrix(1:4,2,2) * m/s * 4 * m/s)
 
 ## ------------------------------------------------------------------------
-as.units(matrix(1:4,2,2), "m/s") %*% as.units(4:3, "m/s")
+with(ud_units, (matrix(1:4,2,2) * m/s) %*% (4:3 * m/s))
 
 ## ------------------------------------------------------------------------
 set.seed(131)
-d = data.frame(x = runif(4), y = as.units(runif(4), "s"), z = as.units(1:4, "m/s"))
+d <- with(ud_units,
+         data.frame(x = runif(4), 
+                    y = runif(4) * s, 
+                    z = 1:4 * m/s))
 d
 summary(d)
 d$yz = with(d, y * z)
 d
 d[1, "yz"]
 
+## ------------------------------------------------------------------------
+(x = 1:10 * make_unit("m2 s-1"))
+
+## ------------------------------------------------------------------------
+y = 1:10 * with(ud_units, m^2/s)
+x + y
+
+## ------------------------------------------------------------------------
+x/y
+
+## ------------------------------------------------------------------------
+(z = 1:10 * parse_unit("m2 s-1"))
+z + y
+z / y
+
+## ------------------------------------------------------------------------
+as_cf(z)
+
